Crate cmark_writer_macros

Crate cmark_writer_macros 

Attribute Macros

coded_error
Custom coded error attribute macro, replaces the coded form errors in the original define_custom_errors! macro
custom_node
Custom node attribute macro for implementing the CustomNode trait
structure_error
Custom error attribute macro, replaces the struct form errors in the original define_custom_errors! macro