Attribute Macros
- coded_
error - Custom coded error attribute macro, replaces the coded form errors in the original define_custom_errors! macro
- custom_
node - Custom node attribute macro for implementing the CustomNode trait
- structure_
error - Custom error attribute macro, replaces the struct form errors in the original define_custom_errors! macro